@@ -1,5 +1,5 @@
 /*
- * $Header: /home/t-ishii/repository/exttable/exttable.c,v 1.2 2003/09/12 12:23:09 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/exttable/exttable.c,v 1.3 2003/11/25 05:25:09 t-ishii Exp $
  *
  * Copyright (c) 2002-2003	Tatsuo Ishii
  *
@@ -43,7 +43,7 @@ extern Datum exttable(PG_FUNCTION_ARGS);
  * exttable(text, char) returns setof record
  *
  * Calling sequence
- * SELECT exttable('/full/path/to/file') AS (f1 int, f2 text, ....);
+ * SELECT exttable('/full/path/to/file', '\t') AS (f1 int, f2 text, ....);
  * ----------
  */
 
@@ -92,7 +92,7 @@ exttable(PG_FUNCTION_ARGS)
 		funcctx->user_fctx = (void *) mystatus;
 
 		/* read the file and set actuaul file contents */
-		path = DatumGetCString(DirectFunctionCall1(textout, PG_GETARG_DATUM(0)));
+		path = DatumGetCString(DirectFunctionCall1(textout, (Datum)PG_GETARG_TEXT_P(0)));
 		p = PG_GETARG_BPCHAR_P(1);
 		delimiter = (char)*(VARDATA(p));
 		readfile(path, mystatus, desc->natts, delimiter);
